@@ -39,13 +39,10 @@ void XHamster::checkUrlIsValid() {
     }
     else {
         QString response(reply->readAll());
-        QString varString = response.simplified().section("var flashvars = ", 1, 1).section("; swf", 0, 0);
-        QString srv = varString.section("'srv': '", 1, 1).section("'", 0, 0);
-        QString file = varString.section("'file': '", 1, 1).section("'", 0, 0);
+        QString varString = QByteArray::fromPercentEncoding(response.section("flashvars\" value=\"", 1, 1).section('"', 0, 0).toUtf8());
 
-        if ((!srv.isEmpty()) && (!file.isEmpty())) {
-            QUrl url(varString.section("xmlfile': '", 1, 1).section("', ", 0, 0));
-            QString fileName = QByteArray::fromPercentEncoding(url.queryItemValue("title").toUtf8()).replace('+', ' ') + ".flv";
+        if (!varString.isEmpty()) {
+            QString fileName = QByteArray::fromPercentEncoding(varString.section("title=", 1, 1).section('&', 0, 0).toUtf8()).replace('+', ' ') + ".flv";
             emit urlChecked(true, reply->request().url(), this->serviceName(), fileName);
         }
         else {
@@ -73,11 +70,13 @@ void XHamster::parseVideoPage() {
     }
 
     QString response(reply->readAll());
-    QString varString = response.simplified().section("var flashvars = ", 1, 1).section("; swf", 0, 0);
-    QString srv = varString.section("'srv': '", 1, 1).section("'", 0, 0);
-    QString file = varString.section("'file': '", 1, 1).section("'", 0, 0);
+    QString varString = response.section("flashvars\" value=\"", 1, 1).section('"', 0, 0);
+
+    if (!varString.isEmpty()) {
+	QUrl url = QUrl::fromEncoded("http://xhamster.com?" + varString.toUtf8());
+	QString srv = url.queryItemValue("srv");
+	QString file = url.queryItemValue("file");
 
-    if ((!srv.isEmpty()) && (!file.isEmpty())) {
         if (file.startsWith("http")) {
             QNetworkRequest request;
             request.setUrl(QUrl(file));
